-- Create syntax for TABLE 'app'
CREATE TABLE `app`
(
    `id`                bigint(20) unsigned NOT NULL AUTO_INCREMENT,
    `code`              varchar(64)         NOT NULL DEFAULT '',
    `name`              varchar(64)         NOT NULL DEFAULT '',
    `master_version_id` bigint(20) unsigned          DEFAULT NULL,
    `create_time`       bigint(20)          NOT NULL,
    `update_time`       bigint(20)          NOT NULL,
    PRIMARY KEY (`id`),
    UNIQUE KEY `code` (`code`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4;

-- Create syntax for TABLE 'app_user'
CREATE TABLE `app_user`
(
    `app_id`  bigint(20) unsigned NOT NULL,
    `user_id` bigint(20) unsigned NOT NULL,
    PRIMARY KEY (`app_id`, `user_id`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4;

-- Create syntax for TABLE 'property_item'
CREATE TABLE `property_item`
(
    `app_id`      bigint(20) unsigned NOT NULL,
    `version_id`  bigint(20) unsigned NOT NULL,
    `module_id`   bigint(20) unsigned NOT NULL,
    `env_id`      bigint(20)          NOT NULL,
    `key`         varchar(64)         NOT NULL DEFAULT '',
    `value`       text                NOT NULL DEFAULT '',
    `comment`     varchar(128)                 DEFAULT NULL,
    `mode`        varchar(16)         NOT NULL,
    `create_time` bigint(20)          NOT NULL,
    `update_time` bigint(20)          NOT NULL,
    PRIMARY KEY (`app_id`, `version_id`, `module_id`, `env_id`, `key`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4;

-- Create syntax for TABLE 'env'
CREATE TABLE `env`
(
    `id`          bigint(20) unsigned NOT NULL AUTO_INCREMENT,
    `app_id`      bigint(20) unsigned NOT NULL,
    `code`        varchar(64)         NOT NULL DEFAULT '',
    `name`        varchar(64)         NOT NULL DEFAULT '',
    `type`        varchar(16)         NOT NULL DEFAULT '',
    `user_id`     bigint(20) unsigned NOT NULL,
    `create_time` bigint(20)          NOT NULL,
    `update_time` bigint(20)          NOT NULL,
    PRIMARY KEY (`id`),
    UNIQUE KEY `code` (`app_id`, `code`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4;

-- Create syntax for TABLE 'module'
CREATE TABLE `module`
(
    `id`          bigint(20) unsigned NOT NULL AUTO_INCREMENT,
    `app_id`      bigint(20) unsigned NOT NULL,
    `code`        varchar(64)         NOT NULL DEFAULT '',
    `name`        varchar(64)         NOT NULL DEFAULT '',
    `enable`      tinyint(1)          NOT NULL,
    `create_time` bigint(20)          NOT NULL,
    `update_time` bigint(20)          NOT NULL,
    PRIMARY KEY (`id`),
    UNIQUE KEY `code` (`app_id`, `code`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4;

-- Create syntax for TABLE 'user'
CREATE TABLE `user`
(
    `id`            bigint(20) unsigned NOT NULL AUTO_INCREMENT,
    `login_name`    varchar(64)         NOT NULL DEFAULT '',
    `name`          varchar(64)         NOT NULL DEFAULT '',
    `password`      varchar(64)         NOT NULL DEFAULT '',
    `role`          varchar(64)         NOT NULL DEFAULT '',
    `enable`        tinyint(1)          NOT NULL DEFAULT 1,
    `export_secret` varchar(64)         NOT NULL DEFAULT '',
    `access_token`  varchar(64)                  DEFAULT NULL,
    `create_time`   bigint(20)          NOT NULL,
    `update_time`   bigint(20)          NOT NULL,
    PRIMARY KEY (`id`),
    UNIQUE KEY `login_name` (`login_name`),
    UNIQUE KEY `export_secret` (`export_secret`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4;

-- Create syntax for TABLE 'version'
CREATE TABLE `version`
(
    `id`            bigint(20) unsigned NOT NULL AUTO_INCREMENT,
    `app_id`        bigint(20) unsigned NOT NULL,
    `name`          varchar(64)         NOT NULL DEFAULT '',
    `main_number`   int(11)             NOT NULL,
    `middle_number` int(11)             NOT NULL,
    `sub_number`    int(11)             NOT NULL,
    `archived`      tinyint(1)          NOT NULL,
    `create_time`   bigint(20)          NOT NULL,
    `update_time`   bigint(20)          NOT NULL,
    PRIMARY KEY (`id`),
    UNIQUE KEY `number` (`app_id`, `main_number`, `middle_number`, `sub_number`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4;

CREATE TABLE `nginx_config`
(
    `app_id`      bigint(20) unsigned NOT NULL,
    `module_id`   bigint(20) unsigned NOT NULL,
    `env_id`      bigint(20)          NOT NULL,
    `content`     text                NOT NULL,
    `create_time` bigint(20)          NOT NULL,
    `update_time` bigint(20)          NOT NULL,
    PRIMARY KEY (`app_id`, `module_id`, `env_id`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4;

INSERT INTO `user` (`login_name`, `name`, `password`, `role`, `access_token`, `export_secret`, `create_time`,
                    `update_time`)
VALUES ('admin', '系统管理员', '51f7be45b644056aa7de7340a56c0409', '[\"ADMIN\"]', '', '42cc190287d3e92c',
        1663727301414, 1666928704263);
